You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by pu...@apache.org on 2013/05/31 22:23:34 UTC

[1/7] git commit: Builds Windows 8 apps

Updated Branches:
  refs/heads/master a3ee95cd5 -> 376145b35


Builds Windows 8 apps


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/8a286249
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/8a286249
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/8a286249

Branch: refs/heads/master
Commit: 8a2862491cf51cd28d41cab64d0318649fdfcaf0
Parents: a3ee95c
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Wed May 29 17:37:56 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Wed May 29 17:37:56 2013 -0700

----------------------------------------------------------------------
 windows8/template/cordova/lib/build.js |   76 +++++++++++----------------
 1 files changed, 31 insertions(+), 45 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/8a286249/windows8/template/cordova/lib/build.js
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
new file mode 100644
index 0000000..75a59c7
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
@@ -0,0 +1,61 @@
+
+#include <stdio.h>
+#include <tchar.h>
+#include <shlobj.h>
+#include <stdio.h>
+#include <shobjidl.h>
+#include <objbase.h>
+#include <atlbase.h>
+#include <string>
+#include <AppxPackaging.h>
+
+int _tmain(int argc, _TCHAR* argv[])
+{
+    DWORD dwProcessId = 0;
+    HRESULT hr = CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
+
+    if(SUCCEEDED(hr))
+    {
+        if(argc == 2)
+        {
+            CComPtr<IAppxManifestReader> spManifestReader;
+
+            CComPtr<IApplicationActivationManager> spAppActivationManager;
+            // get IApplicationActivationManager
+            hr = CoCreateInstance(CLSID_ApplicationActivationManager,
+                                    NULL,
+                                    CLSCTX_LOCAL_SERVER,
+                                    IID_IApplicationActivationManager,
+                                    (LPVOID*)&spAppActivationManager);
+
+            // allow it to be launched in the foreground.
+            if (SUCCEEDED(hr))
+            {
+                hr = CoAllowSetForegroundWindow(spAppActivationManager, NULL);
+            }
+ 
+            // Launch it!
+            if (SUCCEEDED(hr))
+            {  
+                hr = spAppActivationManager->ActivateApplication((LPCWSTR)argv[1],
+                                                                NULL,
+                                                                AO_NONE,
+                                                                &dwProcessId);
+            }
+        }
+        else 
+        {
+            printf("%s","Missing Command Line Argument");
+            hr = E_ABORT;
+        }
+        CoUninitialize();
+    }
+
+    if(SUCCEEDED(hr))
+    {
+       printf("%s","Successfully Deployed.");
+    }
+    
+    return hr;
+}
+

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
deleted file mode 100644
index 970c89f..0000000
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
+++ /dev/null
@@ -1,20 +0,0 @@
-
-Microsoft Visual Studio Solution File, Format Version 12.00
-# Visual Studio 2012
-Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "CordovaWindows8Deploy", "CordovaWindows8Deploy\CordovaWindows8Deploy.vcxproj", "{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}"
-EndProject
-Global
-	GlobalSection(SolutionConfigurationPlatforms) = preSolution
-		Debug|Win32 = Debug|Win32
-		Release|Win32 = Release|Win32
-	EndGlobalSection
-	GlobalSection(ProjectConfigurationPlatforms) = postSolution
-		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Debug|Win32.ActiveCfg = Debug|Win32
-		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Debug|Win32.Build.0 = Debug|Win32
-		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Release|Win32.ActiveCfg = Release|Win32
-		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Release|Win32.Build.0 = Release|Win32
-	EndGlobalSection
-	GlobalSection(SolutionProperties) = preSolution
-		HideSolutionNode = FALSE
-	EndGlobalSection
-EndGlobal

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
new file mode 100644
index 0000000..2b8c4a8
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
@@ -0,0 +1,85 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}</ProjectGuid>
+    <Keyword>Win32Proj</Keyword>
+    <RootNamespace>CordovaWindows8Deploy</RootNamespace>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseDebugLibraries>true</UseDebugLibraries>
+    <PlatformToolset>v110</PlatformToolset>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseDebugLibraries>false</UseDebugLibraries>
+    <PlatformToolset>v110</PlatformToolset>
+    <WholeProgramOptimization>true</WholeProgramOptimization>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <LinkIncremental>true</LinkIncremental>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <LinkIncremental>false</LinkIncremental>
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <Optimization>Disabled</Optimization>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <SDLCheck>true</SDLCheck>
+    </ClCompile>
+    <Link>
+      <SubSystem>Console</SubSystem>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <WarningLevel>Level3</WarningLevel>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <Optimization>MaxSpeed</Optimization>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <IntrinsicFunctions>true</IntrinsicFunctions>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <SDLCheck>true</SDLCheck>
+    </ClCompile>
+    <Link>
+      <SubSystem>Console</SubSystem>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <OptimizeReferences>true</OptimizeReferences>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <ClCompile Include="CordovaWindows8Deploy.cpp" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
+</Project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
deleted file mode 100644
index 5b55d34..0000000
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
+++ /dev/null
@@ -1,56 +0,0 @@
-
-#include <stdio.h>
-#include <tchar.h>
-#include <shlobj.h>
-#include <stdio.h>
-#include <shobjidl.h>
-#include <objbase.h>
-#include <atlbase.h>
-#include <string>
-#include <AppxPackaging.h>
-
-int _tmain(int argc, _TCHAR* argv[])
-{
-    DWORD dwProcessId = 0;
-    HRESULT hr = CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
-
-    if(SUCCEEDED(hr))
-    {
-        if(argc == 2)
-        {
-            CComPtr<IAppxManifestReader> spManifestReader;
-
-            CComPtr<IApplicationActivationManager> spAppActivationManager;
-            // get IApplicationActivationManager
-            hr = CoCreateInstance(CLSID_ApplicationActivationManager,
-                                    NULL,
-                                    CLSCTX_LOCAL_SERVER,
-                                    IID_IApplicationActivationManager,
-                                    (LPVOID*)&spAppActivationManager);
-
-            // allow it to be launched in the foreground.
-            if (SUCCEEDED(hr))
-            {
-                hr = CoAllowSetForegroundWindow(spAppActivationManager, NULL);
-            }
- 
-            // Launch it!
-            if (SUCCEEDED(hr))
-            {  
-                hr = spAppActivationManager->ActivateApplication((LPCWSTR)argv[1],
-                                                                NULL,
-                                                                AO_NONE,
-                                                                &dwProcessId);
-            }
-        }
-        CoUninitialize();
-    }
-
-    if(SUCCEEDED(hr))
-    {
-       printf("%s","Successfully Deployed.");
-    }
-    
-    return hr;
-}
-

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
deleted file mode 100644
index 2b8c4a8..0000000
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
+++ /dev/null
@@ -1,85 +0,0 @@
-<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <ProjectGuid>{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}</ProjectGuid>
-    <Keyword>Win32Proj</Keyword>
-    <RootNamespace>CordovaWindows8Deploy</RootNamespace>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseDebugLibraries>true</UseDebugLibraries>
-    <PlatformToolset>v110</PlatformToolset>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>Application</ConfigurationType>
-    <UseDebugLibraries>false</UseDebugLibraries>
-    <PlatformToolset>v110</PlatformToolset>
-    <WholeProgramOptimization>true</WholeProgramOptimization>
-    <CharacterSet>Unicode</CharacterSet>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <LinkIncremental>true</LinkIncremental>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <LinkIncremental>false</LinkIncremental>
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <PrecompiledHeader>
-      </PrecompiledHeader>
-      <WarningLevel>Level3</WarningLevel>
-      <Optimization>Disabled</Optimization>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <SDLCheck>true</SDLCheck>
-    </ClCompile>
-    <Link>
-      <SubSystem>Console</SubSystem>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <WarningLevel>Level3</WarningLevel>
-      <PrecompiledHeader>Use</PrecompiledHeader>
-      <Optimization>MaxSpeed</Optimization>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <IntrinsicFunctions>true</IntrinsicFunctions>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <SDLCheck>true</SDLCheck>
-    </ClCompile>
-    <Link>
-      <SubSystem>Console</SubSystem>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <EnableCOMDATFolding>true</EnableCOMDATFolding>
-      <OptimizeReferences>true</OptimizeReferences>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClCompile Include="CordovaWindows8Deploy.cpp" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
-</Project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
deleted file mode 100644
index 74ff009..0000000
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
-      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
-      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
-    </Filter>
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="CordovaWindows8Deploy.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-  </ItemGroup>
-</Project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch b/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch
deleted file mode 100644
index ac335aa..0000000
Binary files a/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch and /dev/null differ


[5/7] git commit: CordovaDeploy for Windows 8 - WIP

Posted by pu...@apache.org.
CordovaDeploy for Windows 8 - WIP


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/65ffdf69
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/65ffdf69
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/65ffdf69

Branch: refs/heads/master
Commit: 65ffdf697f80bca20e4411d52c468b99d4601806
Parents: 187202e
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Thu May 30 14:54:32 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Thu May 30 14:54:32 2013 -0700

----------------------------------------------------------------------
 .../CordovaWindows8Deploy.sln                      |   20 ++++
 .../CordovaWindows8Deploy.cpp                      |   52 +++++++++
 .../CordovaWindows8Deploy.vcxproj                  |   88 +++++++++++++++
 .../CordovaWindows8Deploy.vcxproj.filters          |   21 ++++
 .../cordovawindows8deploy-9703390a.ipch            |  Bin 0 -> 77201408 bytes
 5 files changed, 181 insertions(+), 0 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/65ffdf69/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
new file mode 100644
index 0000000..970c89f
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.sln
@@ -0,0 +1,20 @@
+
+Microsoft Visual Studio Solution File, Format Version 12.00
+# Visual Studio 2012
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "CordovaWindows8Deploy", "CordovaWindows8Deploy\CordovaWindows8Deploy.vcxproj", "{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}"
+EndProject
+Global
+	GlobalSection(SolutionConfigurationPlatforms) = preSolution
+		Debug|Win32 = Debug|Win32
+		Release|Win32 = Release|Win32
+	EndGlobalSection
+	GlobalSection(ProjectConfigurationPlatforms) = postSolution
+		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Debug|Win32.ActiveCfg = Debug|Win32
+		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Debug|Win32.Build.0 = Debug|Win32
+		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Release|Win32.ActiveCfg = Release|Win32
+		{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}.Release|Win32.Build.0 = Release|Win32
+	EndGlobalSection
+	GlobalSection(SolutionProperties) = preSolution
+		HideSolutionNode = FALSE
+	EndGlobalSection
+EndGlobal

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/65ffdf69/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
new file mode 100644
index 0000000..1aad14e
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
@@ -0,0 +1,52 @@
+// ConsoleApplication2.cpp : Defines the entry point for the console application.
+//
+
+#include <stdio.h>
+#include <tchar.h>
+#include <shlobj.h>
+#include <stdio.h>
+#include <shobjidl.h>
+#include <objbase.h>
+#include <atlbase.h>
+#include <string>
+
+int _tmain(int argc, _TCHAR* argv[])
+{
+    DWORD dwProcessId = 0;
+    HRESULT hr = CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
+
+    if(SUCCEEDED(hr))
+    {
+        if(argc == 2)
+        {
+
+            CComPtr<IApplicationActivationManager> spAppActivationManager;
+            // get IApplicationActivationManager
+            hr = CoCreateInstance(CLSID_ApplicationActivationManager,
+                                    NULL,
+                                    CLSCTX_LOCAL_SERVER,
+                                    IID_IApplicationActivationManager,
+                                    (LPVOID*)&spAppActivationManager);
+
+            // allow it to be launched in the foreground.
+            if (SUCCEEDED(hr))
+            {
+                hr = CoAllowSetForegroundWindow(spAppActivationManager, NULL);
+            }
+ 
+            // Launch it!
+            if (SUCCEEDED(hr))
+            {  
+                LPCWSTR appId = argv[1];
+                hr = spAppActivationManager->ActivateApplication(appId,
+                                                                NULL,
+                                                                AO_NONE,
+                                                                &dwProcessId);
+            }
+        }
+        CoUninitialize();
+    }
+
+    return hr;
+}
+

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/65ffdf69/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
new file mode 100644
index 0000000..b347864
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
@@ -0,0 +1,88 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup Label="ProjectConfigurations">
+    <ProjectConfiguration Include="Debug|Win32">
+      <Configuration>Debug</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+    <ProjectConfiguration Include="Release|Win32">
+      <Configuration>Release</Configuration>
+      <Platform>Win32</Platform>
+    </ProjectConfiguration>
+  </ItemGroup>
+  <PropertyGroup Label="Globals">
+    <ProjectGuid>{7CE1D306-44A9-40D8-B7CD-135AC2F8150B}</ProjectGuid>
+    <Keyword>Win32Proj</Keyword>
+    <RootNamespace>CordovaWindows8Deploy</RootNamespace>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseDebugLibraries>true</UseDebugLibraries>
+    <PlatformToolset>v110</PlatformToolset>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
+    <ConfigurationType>Application</ConfigurationType>
+    <UseDebugLibraries>false</UseDebugLibraries>
+    <PlatformToolset>v110</PlatformToolset>
+    <WholeProgramOptimization>true</WholeProgramOptimization>
+    <CharacterSet>Unicode</CharacterSet>
+  </PropertyGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
+  <ImportGroup Label="ExtensionSettings">
+  </ImportGroup>
+  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <ImportGroup Label="PropertySheets" Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
+  </ImportGroup>
+  <PropertyGroup Label="UserMacros" />
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <LinkIncremental>true</LinkIncremental>
+  </PropertyGroup>
+  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <LinkIncremental>false</LinkIncremental>
+  </PropertyGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
+    <ClCompile>
+      <PrecompiledHeader>
+      </PrecompiledHeader>
+      <WarningLevel>Level3</WarningLevel>
+      <Optimization>Disabled</Optimization>
+      <PreprocessorDefinitions>WIN32;_DEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <SDLCheck>true</SDLCheck>
+    </ClCompile>
+    <Link>
+      <SubSystem>Console</SubSystem>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
+    <ClCompile>
+      <WarningLevel>Level3</WarningLevel>
+      <PrecompiledHeader>Use</PrecompiledHeader>
+      <Optimization>MaxSpeed</Optimization>
+      <FunctionLevelLinking>true</FunctionLevelLinking>
+      <IntrinsicFunctions>true</IntrinsicFunctions>
+      <PreprocessorDefinitions>WIN32;NDEBUG;_CONSOLE;%(PreprocessorDefinitions)</PreprocessorDefinitions>
+      <SDLCheck>true</SDLCheck>
+    </ClCompile>
+    <Link>
+      <SubSystem>Console</SubSystem>
+      <GenerateDebugInformation>true</GenerateDebugInformation>
+      <EnableCOMDATFolding>true</EnableCOMDATFolding>
+      <OptimizeReferences>true</OptimizeReferences>
+    </Link>
+  </ItemDefinitionGroup>
+  <ItemGroup>
+    <Text Include="ReadMe.txt" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="CordovaWindows8Deploy.cpp" />
+  </ItemGroup>
+  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
+  <ImportGroup Label="ExtensionTargets">
+  </ImportGroup>
+</Project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/65ffdf69/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
new file mode 100644
index 0000000..a31b498
--- /dev/null
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
@@ -0,0 +1,21 @@
+<?xml version="1.0" encoding="utf-8"?>
+<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
+  <ItemGroup>
+    <Filter Include="Source Files">
+      <UniqueIdentifier>{4FC737F1-C7A5-4376-A066-2A32D752A2FF}</UniqueIdentifier>
+      <Extensions>cpp;c;cc;cxx;def;odl;idl;hpj;bat;asm;asmx</Extensions>
+    </Filter>
+    <Filter Include="Resource Files">
+      <UniqueIdentifier>{67DA6AB6-F800-4c08-8B7A-83BB121AAD01}</UniqueIdentifier>
+      <Extensions>rc;ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe;resx;tiff;tif;png;wav;mfcribbon-ms</Extensions>
+    </Filter>
+  </ItemGroup>
+  <ItemGroup>
+    <Text Include="ReadMe.txt" />
+  </ItemGroup>
+  <ItemGroup>
+    <ClCompile Include="CordovaWindows8Deploy.cpp">
+      <Filter>Source Files</Filter>
+    </ClCompile>
+  </ItemGroup>
+</Project>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/65ffdf69/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch b/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch
new file mode 100644
index 0000000..ac335aa
Binary files /dev/null and b/windows8/tooling/CordovaWindows8Deploy/ipch/cordovawindows8deploy-c95ef552/cordovawindows8deploy-9703390a.ipch differ


[3/7] git commit: fixed typo, added template file

Posted by pu...@apache.org.
fixed typo, added template file


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/ab284ef2
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/ab284ef2
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/ab284ef2

Branch: refs/heads/master
Commit: ab284ef2b447eab19bad669438f465c2bf42bd3c
Parents: 8a28624
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Wed May 29 17:53:02 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Wed May 29 17:53:02 2013 -0700

----------------------------------------------------------------------
 windows8/template/MyTemplate.vstemplate |   44 ++++++++++++++++++++++++++
 windows8/template/cordova/lib/build.js  |    2 +-
 2 files changed, 45 insertions(+), 1 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/ab284ef2/windows8/template/MyTemplate.vstemplate
----------------------------------------------------------------------
diff --git a/windows8/template/MyTemplate.vstemplate b/windows8/template/MyTemplate.vstemplate
new file mode 100644
index 0000000..01f7e6f
--- /dev/null
+++ b/windows8/template/MyTemplate.vstemplate
@@ -0,0 +1,44 @@
+<VSTemplate Version="3.0.0" xmlns="http://schemas.microsoft.com/developer/vstemplate/2005" Type="Project">
+  <TemplateData>
+    <Name>CordovaAppWin8</Name>
+    <Description>CordovaAppWin8</Description>
+    <ProjectType>JavaScript</ProjectType>
+    <ProjectSubType>
+    </ProjectSubType>
+    <SortOrder>1000</SortOrder>
+    <CreateNewFolder>true</CreateNewFolder>
+    <DefaultName>CordovaAppWin8</DefaultName>
+    <ProvideDefaultName>true</ProvideDefaultName>
+    <LocationField>Enabled</LocationField>
+    <EnableLocationBrowseButton>true</EnableLocationBrowseButton>
+    <Icon>__TemplateIcon.ico</Icon>
+  </TemplateData>
+  <TemplateContent>
+    <Project TargetFileName="CordovaApp.jsproj" File="CordovaApp.jsproj" ReplaceParameters="true">
+      <Folder Name="images" TargetFolderName="images">
+        <ProjectItem ReplaceParameters="false" TargetFileName="logo.png">logo.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="smalllogo.png">smalllogo.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="splashscreen.png">splashscreen.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="storelogo.png">storelogo.png</ProjectItem>
+      </Folder>
+      <Folder Name="www" TargetFolderName="www">
+        <Folder Name="css" TargetFolderName="css">
+          <ProjectItem ReplaceParameters="true" TargetFileName="index.css">index.css</ProjectItem>
+        </Folder>
+        <Folder Name="img" TargetFolderName="img">
+          <ProjectItem ReplaceParameters="false" TargetFileName="logo.png">logo.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="smalllogo.png">smalllogo.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="splashscreen.png">splashscreen.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="storelogo.png">storelogo.png</ProjectItem>
+        </Folder>
+        <Folder Name="js" TargetFolderName="js">
+          <ProjectItem ReplaceParameters="true" TargetFileName="index.js">index.js</ProjectItem>
+        </Folder>
+        <ProjectItem ReplaceParameters="true" TargetFileName="cordova.js">cordova.js</ProjectItem>
+        <ProjectItem ReplaceParameters="true" TargetFileName="index.html">index.html</ProjectItem>
+      </Folder>
+      <ProjectItem ReplaceParameters="false" TargetFileName="CordovaApp_TemporaryKey.pfx">CordovaApp_TemporaryKey.pfx</ProjectItem>
+      <ProjectItem ReplaceParameters="true" TargetFileName="package.appxmanifest">package.appxmanifest</ProjectItem>
+    </Project>
+  </TemplateContent>
+</VSTemplate>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/ab284ef2/windows8/template/cordova/lib/build.js
----------------------------------------------------------------------
diff --git a/windows8/template/cordova/lib/build.js b/windows8/template/cordova/lib/build.js
index a307be2..5cc0533 100644
--- a/windows8/template/cordova/lib/build.js
+++ b/windows8/template/cordova/lib/build.js
@@ -71,7 +71,7 @@ function exec_verbose(command) {
     }
 }
 
-// checks to see if a .csproj file exists in the project root
+// checks to see if a .jsproj file exists in the project root
 function is_cordova_project(path) {
     if (fso.FolderExists(path)) {
         var proj_folder = fso.GetFolder(path);


[4/7] git commit: Merge branch 'master' of github.com:purplecabbage/cordova-windows

Posted by pu...@apache.org.
Merge branch 'master' of github.com:purplecabbage/cordova-windows


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/187202ef
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/187202ef
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/187202ef

Branch: refs/heads/master
Commit: 187202ef16df535c8e36a93e99e91159aa123a83
Parents: ab284ef 6d5e43e
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Wed May 29 17:53:47 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Wed May 29 17:53:47 2013 -0700

----------------------------------------------------------------------
 windows8/template/package.appxmanifest |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------



[2/7] git commit: added template replacable values

Posted by pu...@apache.org.
added template replacable values


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/6d5e43e6
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/6d5e43e6
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/6d5e43e6

Branch: refs/heads/master
Commit: 6d5e43e6a0b88a4a84c1941be0c7a4c2fd66ca68
Parents: 8a28624
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Wed May 29 17:40:29 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Wed May 29 17:40:29 2013 -0700

----------------------------------------------------------------------
 windows8/template/MyTemplate.vstemplate |   44 ++++++++++++++++++++++++++
 windows8/template/package.appxmanifest  |   10 +++---
 2 files changed, 49 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/6d5e43e6/windows8/template/MyTemplate.vstemplate
----------------------------------------------------------------------
diff --git a/windows8/template/MyTemplate.vstemplate b/windows8/template/MyTemplate.vstemplate
new file mode 100644
index 0000000..01f7e6f
--- /dev/null
+++ b/windows8/template/MyTemplate.vstemplate
@@ -0,0 +1,44 @@
+<VSTemplate Version="3.0.0" xmlns="http://schemas.microsoft.com/developer/vstemplate/2005" Type="Project">
+  <TemplateData>
+    <Name>CordovaAppWin8</Name>
+    <Description>CordovaAppWin8</Description>
+    <ProjectType>JavaScript</ProjectType>
+    <ProjectSubType>
+    </ProjectSubType>
+    <SortOrder>1000</SortOrder>
+    <CreateNewFolder>true</CreateNewFolder>
+    <DefaultName>CordovaAppWin8</DefaultName>
+    <ProvideDefaultName>true</ProvideDefaultName>
+    <LocationField>Enabled</LocationField>
+    <EnableLocationBrowseButton>true</EnableLocationBrowseButton>
+    <Icon>__TemplateIcon.ico</Icon>
+  </TemplateData>
+  <TemplateContent>
+    <Project TargetFileName="CordovaApp.jsproj" File="CordovaApp.jsproj" ReplaceParameters="true">
+      <Folder Name="images" TargetFolderName="images">
+        <ProjectItem ReplaceParameters="false" TargetFileName="logo.png">logo.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="smalllogo.png">smalllogo.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="splashscreen.png">splashscreen.png</ProjectItem>
+        <ProjectItem ReplaceParameters="false" TargetFileName="storelogo.png">storelogo.png</ProjectItem>
+      </Folder>
+      <Folder Name="www" TargetFolderName="www">
+        <Folder Name="css" TargetFolderName="css">
+          <ProjectItem ReplaceParameters="true" TargetFileName="index.css">index.css</ProjectItem>
+        </Folder>
+        <Folder Name="img" TargetFolderName="img">
+          <ProjectItem ReplaceParameters="false" TargetFileName="logo.png">logo.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="smalllogo.png">smalllogo.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="splashscreen.png">splashscreen.png</ProjectItem>
+          <ProjectItem ReplaceParameters="false" TargetFileName="storelogo.png">storelogo.png</ProjectItem>
+        </Folder>
+        <Folder Name="js" TargetFolderName="js">
+          <ProjectItem ReplaceParameters="true" TargetFileName="index.js">index.js</ProjectItem>
+        </Folder>
+        <ProjectItem ReplaceParameters="true" TargetFileName="cordova.js">cordova.js</ProjectItem>
+        <ProjectItem ReplaceParameters="true" TargetFileName="index.html">index.html</ProjectItem>
+      </Folder>
+      <ProjectItem ReplaceParameters="false" TargetFileName="CordovaApp_TemporaryKey.pfx">CordovaApp_TemporaryKey.pfx</ProjectItem>
+      <ProjectItem ReplaceParameters="true" TargetFileName="package.appxmanifest">package.appxmanifest</ProjectItem>
+    </Project>
+  </TemplateContent>
+</VSTemplate>
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/6d5e43e6/windows8/template/package.appxmanifest
----------------------------------------------------------------------
diff --git a/windows8/template/package.appxmanifest b/windows8/template/package.appxmanifest
index c864386..6cea093 100644
--- a/windows8/template/package.appxmanifest
+++ b/windows8/template/package.appxmanifest
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8"?>
 <Package xmlns="http://schemas.microsoft.com/appx/2010/manifest">
-  <Identity Name="efffab2f-bfc5-4eda-b545-45ef4995f55a" Version="1.0.0.0" Publisher="CN=Jesse" />
+  <Identity Name="$guid1$" Version="1.0.0.0" Publisher="CN=$username$" />
   <Properties>
-    <DisplayName>CordovaApp</DisplayName>
-    <PublisherDisplayName>Jesse</PublisherDisplayName>
+    <DisplayName>$projectname$</DisplayName>
+    <PublisherDisplayName>$username$</PublisherDisplayName>
     <Logo>images\storelogo.png</Logo>
   </Properties>
   <Prerequisites>
@@ -14,8 +14,8 @@
     <Resource Language="x-generate" />
   </Resources>
   <Applications>
-    <Application Id="App" StartPage="www/index.html">
-      <VisualElements DisplayName="CordovaApp" 
+    <Application Id="$safeprojectname$" StartPage="www/index.html">
+      <VisualElements DisplayName="$projectname$" 
                       Logo="www\img\logo.png" 
                       SmallLogo="www\img\smalllogo.png"
                       Description="CordovaApp" 


[6/7] git commit: prints success, removed file

Posted by pu...@apache.org.
prints success, removed file


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/0721878e
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/0721878e
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/0721878e

Branch: refs/heads/master
Commit: 0721878e23905bd01c0a5bb00f6a3481eb007e50
Parents: 65ffdf6
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Fri May 31 12:42:44 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Fri May 31 12:42:44 2013 -0700

----------------------------------------------------------------------
 .../CordovaWindows8Deploy.cpp                      |   12 ++++++++----
 .../CordovaWindows8Deploy.vcxproj                  |    3 ---
 .../CordovaWindows8Deploy.vcxproj.filters          |    3 ---
 3 files changed, 8 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/0721878e/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
index 1aad14e..5b55d34 100644
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
@@ -1,5 +1,3 @@
-// ConsoleApplication2.cpp : Defines the entry point for the console application.
-//
 
 #include <stdio.h>
 #include <tchar.h>
@@ -9,6 +7,7 @@
 #include <objbase.h>
 #include <atlbase.h>
 #include <string>
+#include <AppxPackaging.h>
 
 int _tmain(int argc, _TCHAR* argv[])
 {
@@ -19,6 +18,7 @@ int _tmain(int argc, _TCHAR* argv[])
     {
         if(argc == 2)
         {
+            CComPtr<IAppxManifestReader> spManifestReader;
 
             CComPtr<IApplicationActivationManager> spAppActivationManager;
             // get IApplicationActivationManager
@@ -37,8 +37,7 @@ int _tmain(int argc, _TCHAR* argv[])
             // Launch it!
             if (SUCCEEDED(hr))
             {  
-                LPCWSTR appId = argv[1];
-                hr = spAppActivationManager->ActivateApplication(appId,
+                hr = spAppActivationManager->ActivateApplication((LPCWSTR)argv[1],
                                                                 NULL,
                                                                 AO_NONE,
                                                                 &dwProcessId);
@@ -47,6 +46,11 @@ int _tmain(int argc, _TCHAR* argv[])
         CoUninitialize();
     }
 
+    if(SUCCEEDED(hr))
+    {
+       printf("%s","Successfully Deployed.");
+    }
+    
     return hr;
 }
 

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/0721878e/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
index b347864..2b8c4a8 100644
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj
@@ -77,9 +77,6 @@
     </Link>
   </ItemDefinitionGroup>
   <ItemGroup>
-    <Text Include="ReadMe.txt" />
-  </ItemGroup>
-  <ItemGroup>
     <ClCompile Include="CordovaWindows8Deploy.cpp" />
   </ItemGroup>
   <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />

http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/0721878e/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
----------------------------------------------------------------------
diff --git a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
index a31b498..74ff009 100644
--- a/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
+++ b/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy/CordovaWindows8Deploy.vcxproj.filters
@@ -11,9 +11,6 @@
     </Filter>
   </ItemGroup>
   <ItemGroup>
-    <Text Include="ReadMe.txt" />
-  </ItemGroup>
-  <ItemGroup>
     <ClCompile Include="CordovaWindows8Deploy.cpp">
       <Filter>Source Files</Filter>
     </ClCompile>
diff --git a/windows8/template/cordova/lib/build.js b/windows8/template/cordova/lib/build.js
index 9986a7e..a307be2 100644
--- a/windows8/template/cordova/lib/build.js
+++ b/windows8/template/cordova/lib/build.js
@@ -52,7 +52,7 @@ function Log(msg, error) {
 
 // executes a commmand in the shell
 function exec_verbose(command) {
-    //Log("Command: " + command);
+    Log("Command: " + command);
     var oShell=wscript_shell.Exec(command);
     while (oShell.Status == 0) {
         //Wait a little bit so we're not super looping
@@ -77,7 +77,7 @@ function is_cordova_project(path) {
         var proj_folder = fso.GetFolder(path);
         var proj_files = new Enumerator(proj_folder.Files);
         for (;!proj_files.atEnd(); proj_files.moveNext()) {
-            if (fso.GetExtensionName(proj_files.item()) == 'csproj') {
+            if (fso.GetExtensionName(proj_files.item()) == 'jsproj') {
                 return true;  
             }
         }
@@ -85,51 +85,37 @@ function is_cordova_project(path) {
     return false;
 }
 
-// builds the project and .xap in release mode
-function build_xap_release(path) {
-    Log("Building Cordova-WP8 Project:");
-    Log("\tConfiguration : Release");
-    Log("\tDirectory : " + path);
-    
-    wscript_shell.CurrentDirectory = path;
-    exec_verbose('msbuild /clp:NoSummary;NoItemAndPropertyList;Verbosity=minimal /nologo /p:Configuration=Release');
-    
-    // check if file xap was created
-    if (fso.FolderExists(path + '\\Bin\\Release')) {
-        var out_folder = fso.GetFolder(path + '\\Bin\\Release');
-        var out_files = new Enumerator(out_folder.Files);
-        for (;!out_files.atEnd(); out_files.moveNext()) {
-            if (fso.GetExtensionName(out_files.item()) == 'xap') {
-                Log("BUILD SUCCESS.");
-                return;  
-            }
-        }
-    }
-    Log('ERROR: MSBuild failed to create .xap when building cordova-wp8 for release.', true);
-    WScript.Quit(2);
-}
-
 // builds the project and .xap in debug mode
-function build_xap_debug(path) {
-    Log("Building Cordova-WP8 Project:");
-    Log("\tConfiguration : Debug");
+function build_appx(path,isRelease) {
+
+    var mode = (isRelease ? "Release" : "Debug");
+    Log("Building Cordova Windows 8 Project:");
+    Log("\tConfiguration : " + mode);
     Log("\tDirectory : " + path);
     
     wscript_shell.CurrentDirectory = path;
-    exec_verbose('msbuild /clp:NoSummary;NoItemAndPropertyList;Verbosity=minimal /nologo /p:Configuration=Debug');
-    
-    // check if file xap was created
-    if (fso.FolderExists(path + '\\Bin\\Debug')) {
-        var out_folder = fso.GetFolder(path + '\\Bin\\Debug');
-        var out_files = new Enumerator(out_folder.Files);
-        for (;!out_files.atEnd(); out_files.moveNext()) {
-            if (fso.GetExtensionName(out_files.item()) == 'xap') {
-                Log("BUILD SUCCESS.");
-                return;  
+    exec_verbose('msbuild /clp:NoSummary;NoItemAndPropertyList;Verbosity=minimal /nologo /p:Configuration=' + mode);
+
+    // check if file appx was created
+    if (fso.FolderExists(path + '\\AppPackages')) {
+        var out_folder = fso.GetFolder(path + '\\AppPackages');
+        var subFolders = new Enumerator(out_folder.SubFolders);
+        for(;!subFolders.atEnd();subFolders.moveNext())
+        {
+            var subFolder = subFolders.item();
+            var files = new Enumerator(subFolder.Files);
+            for(;!files.atEnd();files.moveNext())
+            {
+                if(fso.GetExtensionName(files.item()) == "appx")
+                {
+                    Log("BUILD SUCCESS.");
+                    return;  
+                }
             }
         }
+
     }
-    Log('ERROR: MSBuild failed to create .xap when building cordova-wp8 for debugging.', true);
+    Log('ERROR: MSBuild failed to create .appx when building cordova-windows8', true);
     WScript.Quit(2);
 }
 
@@ -156,12 +142,12 @@ if (args.Count() > 0) {
         }
 
         if (args(0) == "--debug" || args(0) == "-d") {
-            exec_verbose('%comspec% /c ' + ROOT + '\\cordova\\clean');
-            build_xap_debug(ROOT);
+            //exec_verbose('%comspec% /c ' + ROOT + '\\cordova\\clean');
+            build_appx(ROOT,false);
         }
         else if (args(0) == "--release" || args(0) == "-r") {
-            exec_verbose('%comspec% /c ' + ROOT + '\\cordova\\clean');
-            build_xap_release(ROOT);
+            //exec_verbose('%comspec% /c ' + ROOT + '\\cordova\\clean');
+            build_appx(ROOT,true);
         }
         else {
             Log("Error: \"" + args(0) + "\" is not recognized as a build option", true);
@@ -177,5 +163,5 @@ if (args.Count() > 0) {
 }
 else {
     Log("WARNING: [ --debug | --release ] not specified, defaulting to debug...");
-    build_xap_debug(ROOT);
+    build_appx(ROOT,false);
 }


[7/7] git commit: deleted solution, simplified proj

Posted by pu...@apache.org.
deleted solution, simplified proj


Project: http://git-wip-us.apache.org/repos/asf/cordova-windows/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-windows/commit/376145b3
Tree: http://git-wip-us.apache.org/repos/asf/cordova-windows/tree/376145b3
Diff: http://git-wip-us.apache.org/repos/asf/cordova-windows/diff/376145b3

Branch: refs/heads/master
Commit: 376145b35becbe9792e420994e868f61aeba36e1
Parents: 0721878
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Fri May 31 13:21:04 2013 -0700
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Fri May 31 13:21:04 2013 -0700

----------------------------------------------------------------------
 .../CordovaWindows8Deploy.cpp                      |   61 +++++++++++
 .../CordovaWindows8Deploy.sln                      |   20 ----
 .../CordovaWindows8Deploy.vcxproj                  |   85 +++++++++++++++
 .../CordovaWindows8Deploy.cpp                      |   56 ----------
 .../CordovaWindows8Deploy.vcxproj                  |   85 ---------------
 .../CordovaWindows8Deploy.vcxproj.filters          |   18 ---
 .../cordovawindows8deploy-9703390a.ipch            |  Bin 77201408 -> 0 bytes
 7 files changed, 146 insertions(+), 179 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-windows/blob/376145b3/windows8/tooling/CordovaWindows8Deploy/CordovaWindows8Deploy.cpp
----------------------------------------------------------------------